document.addEventListener('DOMContentLoaded', () => {
  const fileUpload = document.getElementById('file-upload');
  const gallery = document.getElementById('gallery');
  const uploadPreview = document.getElementById('upload-preview');

  // Store images in localStorage
  const savedImages = JSON.parse(localStorage.getItem('gallery-images') || '[]');
  
  // Load saved images
  savedImages.forEach(createGalleryItem);

  fileUpload.addEventListener('change', handleFileUpload);

  function handleFileUpload(e) {
    const files = Array.from(e.target.files);
    
    files.forEach(file => {
      if (!file.type.startsWith('image/')) return;

      const reader = new FileReader();
      
      reader.onload = (event) => {
        const imageData = event.target.result;
        savedImages.push(imageData);
        localStorage.setItem('gallery-images', JSON.stringify(savedImages));
        createGalleryItem(imageData);
      };

      reader.readAsDataURL(file);
    });
  }

  function createGalleryItem(imageData) {
    const item = document.createElement('div');
    item.className = 'gallery-item';
    
    const img = document.createElement('img');
    img.src = imageData;
    img.alt = 'Gallery image';
    
    const downloadBtn = document.createElement('a');
    downloadBtn.className = 'download-btn';
    downloadBtn.innerHTML = 'Download';
    downloadBtn.href = imageData;
    downloadBtn.download = `image-${Date.now()}.jpg`;
    
    item.appendChild(img);
    item.appendChild(downloadBtn);
    gallery.appendChild(item);
  }
});
